conf_rank <-
  sim <-
  conf <-
  tied_teams <-
  div_winner <-
  division <-
  team <-
  div_best_left <-
  win_pct <-
  team_opp <-
  opp <-
  sov <-
  sos <-
  h2h_played <-
  new_rank <-
  div_rank <-
  conf_pct <-
  div_pct <-
  draft_order <-
  new_do <-
  playoff_seeds <-
  game_type <-
  outcome <-
  wins <-
  division_opp <-
  conf_opp <-
  div_game <-
  conf_game <-
  wins_opp <-
  games_opp <-
  h2h_games <-
  draft_order <-
  exit <-
  week <-
  away_team <-
  home_team <-
  result <-
  seed_num <-
  value <-
  tied <-
  do_num <-
  seed <-
  max_reg_week <-
  season <-
  . <-
  round_rank.x <-
  round_rank.y <-
  seed.x <-
  seed.y <-
  team.x <-
  team.y <-
  estimate <-
  true_wins <-
  elo <-
  home_elo <-
  away_elo <-
  elo_diff <-
  home_rest <-
  away_rest <-
  elo_input <-
  elo_mult <-
  wp <-
  elo_shift <-
  problem <-
  away_wins <-
  home_wins <-
  ties <-
  games_played <-
  playoff <-
  afc_division <-
  nfc_division <-
  team_abbr <-
  team_logo_espn <-
  nfc_team <-
  losses <-
  NULL
